1. clone repository and cd into the directory
2. create a virtual environment with [python3 -m venv my_venv]
3. activate the virtual environment with [source my_venv/bin/activate]
4. install requirements [pip3 install -r requirements.txt]
5. run [python3 app.py]
6. go to http://localhost:5000/ in browser
7. deactivate the virtual env with [deactivate]


Discord Commands:
!register username platform
    Links your discord to the provided battlenetusername so all consecutive commands apply to that battlenet

!kd
    prints your kd

!lobby
    prints the stats of the last lobby
    stats include: average lifetime kd, average match kd, highest kd player, highest kd team, diamond/gold/silver etc,
    the entire stat list of your team

!win
    prints the date of your last win, along with your teammates
    
!stats
    prints your stats